# frozen_string_literal: true

module Hermes
  module Api
    module Dmo
      # checker Api::Dmo::HermesController avant d'ajouter des methodes
      class EligibleCountOffersController < Hermes::Api::Dmo::ApplicationController

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          housing_offer_id
          offer_status
          created_at
          updated_at
        ].freeze

        REGEX_PARAMS = %w[
        ].freeze

        MUTATE_PARAMS = %i[
        ].freeze

        def self.acceptable_params
          ACCEPTABLE_PARAMS
        end 

        def self.regex_params
          REGEX_PARAMS
        end 

        def mutate_params
          MUTATE_PARAMS
        end 


        def can_see
          !(current_user_roles & ['Administrator', 'superadministrateur']).empty?
        end 

        def show 
          return render_json_error(:unauthorized, :cannot_see) unless can_see

          super 
        end 

        def index
          return render_json_error(:unauthorized, :cannot_see) unless can_see

          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          @query_precision ||= {}
  
          paginate(
            index_aggregation(no_acl: true),
            each_serializer: @serializer,
            **@options
          )
        end

      end
    end
  end
end
